package com.ruoyi.system.service.impl.projectV2;

import java.util.ArrayList;
import java.util.List;

import com.ruoyi.common.constant.CommonConstants;
import com.ruoyi.common.core.domain.entity.SysRole;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.projectV2.ZsyzDjks;
import com.ruoyi.system.domain.projectV2.ZsyzFj;
import com.ruoyi.system.mapper.projectV2.ZsyzFjMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.projectV2.ZsyzWczsMapper;
import com.ruoyi.system.domain.projectV2.ZsyzWczs;
import com.ruoyi.system.service.projectV2.IZsyzWczsService;

import static com.ruoyi.common.constant.CommonConstants.LEADER;
import static com.ruoyi.common.constant.CommonConstants.MANAGE;

/**
 * 招商引资_外出招商Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-03-16
 */
@Service
public class ZsyzWczsServiceImpl implements IZsyzWczsService 
{
    @Autowired
    private ZsyzWczsMapper zsyzWczsMapper;
    @Autowired
    private ZsyzFjMapper zsyzFjMapper;

    /**
     * 查询招商引资_外出招商
     * 
     * @param id 招商引资_外出招商主键
     * @return 招商引资_外出招商
     */
    @Override
    public ZsyzWczs selectZsyzWczsById(Long id)
    {
        ZsyzWczs zsyzWczs = zsyzWczsMapper.selectZsyzWczsById(id);

        if(zsyzWczs.getZsyzFjList().size()==1 && StringUtils.isEmpty(zsyzWczs.getZsyzFjList().get(0).getPath())){
            zsyzWczs.setZsyzFjList(new ArrayList<>());
            return zsyzWczs ;
        }
        if(zsyzWczs.getZsyzFjList().size()<=0){
            zsyzWczs.setZsyzFjList(new ArrayList<>());
        }else{
            List<ZsyzFj> zsyzFjList = new ArrayList<>();
            //只拿type为7的附件
            for (ZsyzFj zsyzFj : zsyzWczs.getZsyzFjList()) {
                if(zsyzFj.getType().equals(CommonConstants.SEV)){
                    zsyzFjList.add(zsyzFj);
                }
            }
            zsyzWczs.setZsyzFjList(zsyzFjList);
        }

        return zsyzWczs;
    }

    /**
     * 查询招商引资_外出招商列表
     * 
     * @param zsyzWczs 招商引资_外出招商
     * @return 招商引资_外出招商
     */
    @Override
    public List<ZsyzWczs> selectZsyzWczsList(ZsyzWczs zsyzWczs)
    {
        SysUser currentUser = SecurityUtils.getLoginUser().getUser();
        String roleKey = "";
        // 如果是超级管理员/管理员，则不过滤数据
        List<SysRole> roles = SecurityUtils.getLoginUser().getUser().getRoles();
        if (roles != null && roles.size() > 0) {
            roleKey = roles.get(0).getRoleKey();
        }
        if (StringUtils.isNotNull(currentUser) && (currentUser.isAdmin() || MANAGE.equals(roleKey) || LEADER.equals(roleKey))) {
            //如果是admin/或者平台管理员/或者领导 获取到所有数据

        }else{
            zsyzWczs.setDeptId(currentUser.getDeptId());
        }
        return zsyzWczsMapper.selectZsyzWczsList(zsyzWczs);
    }

    /**
     * 新增招商引资_外出招商
     * 
     * @param zsyzWczs 招商引资_外出招商
     * @return 结果
     */
    @Override
    public int insertZsyzWczs(ZsyzWczs zsyzWczs)
    {
        SysUser user = SecurityUtils.getLoginUser().getUser();
        zsyzWczs.setDeptId(user.getDeptId());
        zsyzWczs.setDeptName(user.getDept().getDeptName());
        zsyzWczs.setCreateTime(DateUtils.getNowDate());
        int count = zsyzWczsMapper.insertZsyzWczs(zsyzWczs);
        //修改附件
        if (zsyzWczs.getZsyzFjList() != null && zsyzWczs.getZsyzFjList().size() > 0) {
            ZsyzFj zsyzFjDelete = new ZsyzFj();
            zsyzFjDelete.setSourceId(zsyzWczs.getId());
            zsyzFjDelete.setType(CommonConstants.SEV);
            //先删除相关附件
            zsyzFjMapper.deleteZsyzFjBySourceId(zsyzFjDelete);
            //再将文件新增进数据库
            List<ZsyzFj> zsyzFjList = zsyzWczs.getZsyzFjList();
            if (zsyzFjList != null) {
                for (ZsyzFj zsyzFj : zsyzFjList) {
                    zsyzFj.setSourceId(zsyzWczs.getId());
                    zsyzFj.setType(CommonConstants.SEV);
                    zsyzFj.setXmId(0L);
                    zsyzFjMapper.insertZsyzFj(zsyzFj);
                }
            }
        }
        return count;
    }

    /**
     * 修改招商引资_外出招商
     * 
     * @param zsyzWczs 招商引资_外出招商
     * @return 结果
     */
    @Override
    public int updateZsyzWczs(ZsyzWczs zsyzWczs)
    {
        zsyzWczs.setUpdateTime(DateUtils.getNowDate());
        //修改附件
        ZsyzFj zsyzFjDelete = new ZsyzFj();
        zsyzFjDelete.setSourceId(zsyzWczs.getId());
        zsyzFjDelete.setType(CommonConstants.SEV);
        //先删除相关附件
        zsyzFjMapper.deleteZsyzFjBySourceId(zsyzFjDelete);
        //再将文件新增进数据库
        List<ZsyzFj> zsyzFjList = zsyzWczs.getZsyzFjList();
        if (zsyzFjList != null) {
            for (ZsyzFj zsyzFj : zsyzFjList) {
                zsyzFj.setSourceId(zsyzWczs.getId());
                zsyzFj.setType(CommonConstants.SEV);
                zsyzFj.setXmId(0L);
                zsyzFjMapper.insertZsyzFj(zsyzFj);
            }
        }
        return zsyzWczsMapper.updateZsyzWczs(zsyzWczs);
    }

    /**
     * 批量删除招商引资_外出招商
     * 
     * @param ids 需要删除的招商引资_外出招商主键
     * @return 结果
     */
    @Override
    public int deleteZsyzWczsByIds(Long[] ids)
    {
        return zsyzWczsMapper.deleteZsyzWczsByIds(ids);
    }

    /**
     * 删除招商引资_外出招商信息
     * 
     * @param id 招商引资_外出招商主键
     * @return 结果
     */
    @Override
    public int deleteZsyzWczsById(Long id)
    {
        return zsyzWczsMapper.deleteZsyzWczsById(id);
    }
}
