package com.ruoyi.web.controller.projectV2;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.projectV2.ZsyzWczs;
import com.ruoyi.system.service.projectV2.IZsyzWczsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 招商引资_外出招商Controller
 * 
 * @author ruoyi
 * @date 2023-03-16
 */
@RestController
@RequestMapping("/projectV2/wczs")
public class ZsyzWczsController extends BaseController
{
    @Autowired
    private IZsyzWczsService zsyzWczsService;

    /**
     * 查询招商引资_外出招商列表
     */
    @PreAuthorize("@ss.hasPermi('system:wczs:list')")
    @GetMapping("/list")
    public TableDataInfo list(ZsyzWczs zsyzWczs)
    {
        startPage();
        List<ZsyzWczs> list = zsyzWczsService.selectZsyzWczsList(zsyzWczs);
        return getDataTable(list);
    }

    /**
     * 导出招商引资_外出招商列表
     */
    @PreAuthorize("@ss.hasPermi('system:wczs:export')")
    @Log(title = "招商引资_外出招商", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ZsyzWczs zsyzWczs)
    {
        List<ZsyzWczs> list = zsyzWczsService.selectZsyzWczsList(zsyzWczs);
        ExcelUtil<ZsyzWczs> util = new ExcelUtil<ZsyzWczs>(ZsyzWczs.class);
        util.exportExcel(response, list, "招商引资_外出招商数据");
    }

    /**
     * 获取招商引资_外出招商详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:wczs:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(zsyzWczsService.selectZsyzWczsById(id));
    }

    /**
     * 新增招商引资_外出招商
     */
    @PreAuthorize("@ss.hasPermi('system:wczs:add')")
    @Log(title = "招商引资_外出招商", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ZsyzWczs zsyzWczs)
    {
        return toAjax(zsyzWczsService.insertZsyzWczs(zsyzWczs));
    }

    /**
     * 修改招商引资_外出招商
     */
    @PreAuthorize("@ss.hasPermi('system:wczs:edit')")
    @Log(title = "招商引资_外出招商", businessType = BusinessType.UPDATE)
    @PostMapping("/put")
    public AjaxResult edit(@RequestBody ZsyzWczs zsyzWczs)
    {
        return toAjax(zsyzWczsService.updateZsyzWczs(zsyzWczs));
    }

    /**
     * 删除招商引资_外出招商
     */
    @PreAuthorize("@ss.hasPermi('system:wczs:remove')")
    @Log(title = "招商引资_外出招商", businessType = BusinessType.DELETE)
	@GetMapping("/delete/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(zsyzWczsService.deleteZsyzWczsByIds(ids));
    }
}
